@@ -12,10 +12,10 @@ class ParseArguments:
 		parser.add_argument('-B', '--block', action="store_true", default=False, help="Use block compression option. This mode allows highly multi-threaded compression/decompression with random read access allowing compressed games to be played without decompression in the future however this comes with a slightly lower compression ratio cost. This is the default option for XCZ.")
 		parser.add_argument('-S', '--solid', action="store_true", default=False, help="Use solid compression option. Slightly higher compression ratio but won't allow for random read access. File compressed this way will never be mountable (have to be installed or decompressed first to run). This is the default option for NSZ.")
 		parser.add_argument('-s', '--bs', type=int, default=20, help='Block Size for random read access 2^x while x between 14 and 32. Default: 20 => 1 MB')
-		parser.add_argument('-V', '--verify', action="store_true", default=False, help='Verifies files after compression raising an unhandled exception on hash mismatch and verify existing NSP and NSZ files when given as parameter. Requires --keep-delta when used during compression.')
-		parser.add_argument('-Q', '--quick-verify', action="store_true", default=False, help='Same as --verify but skips the expensive and mostly useless PFS0 hash verification and only verifies NCA hashes. Does not require --keep-delta when used during compression.')
-		parser.add_argument('-K', '--keep-delta', action="store_true", default=False, help='Keep all useless delta fragments (NDV0) during compression so the NSP (PFS0) can be recreated bit-identical during decompression')
-		parser.add_argument('-R', '--remove-padding', action="store_true", default=False, help='Remove the padding between the PFS0 header and the first file so the NSP matches the nxdumptool/no-intro standard. This also removes padding added to the FileEntryTable as there should not be any padding there.')
+		parser.add_argument('-V', '--verify', action="store_true", default=False, help='Verifies files after compression raising an unhandled exception on hash mismatch and verify existing NSP and NSZ files when given as parameter. Requires --keep when used during compression.')
+		parser.add_argument('-Q', '--quick-verify', action="store_true", default=False, help='Same as --verify but skips the NSP SHA256 hash verification and only verifies NCA hashes. Does not require --keep when used during compression.')
+		parser.add_argument('-K', '--keep', action="store_true", default=False, help='Keep all useless files and partitions during compression to allow bit-identical recreation')
+		parser.add_argument('-F', '--fix-padding', action="store_true", default=False, help='Fixes PFS0 padding to match the nxdumptool/no-intro standard. Incompatible with --verify so --quick-verify will be used instead.')
 		parser.add_argument('-p', '--parseCnmt', action="store_true", default=False, help='Extract TitleId/Version from Cnmt if this information cannot be obtained from the filename. Required for skipping/overwriting existing files and --rm-old-version to work properly if some not every file is named properly. Supported filenames: *TitleID*[vVersion]*')
 		parser.add_argument('-P', '--alwaysParseCnmt', action="store_true", default=False, help='Always extract TitleId/Version from Cnmt and never trust filenames')
 		parser.add_argument('-t', '--threads', type=int, default=-1, help='Number of threads to compress with. Numbers < 1 corresponds to the number of logical CPU cores for block compression and 3 for solid compression')
